---
name: New Feature
about: 'API'
title: 'Implement a new feature'
labels: 'enhancement'
assignees: ''
---

<!-- Description of the new feature -->


#### New feature Code Sample
<!-- Describe the new feature API here -->

```python
# Your code here

```

#### Changes proposed in this pull request

-
-

#### Task list
- [] Closes #.
- [] CI tests added
- [] If necessary, update dependencies in ``pyproject.toml.txt`` that are required for this new feature
- [] Fully documented, including ``api.rst`` for new API
